
> [!WARNING]
> This project is an independent Python Port of the [Julia project](https://github.com/ITensor/ITensors.jl). We are not officially affiliated with Flatiron nor the authors of ITensor.

![PyPI - Version](https://img.shields.io/pypi/v/itensors)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/itensors)
![PyPI - Format](https://img.shields.io/pypi/format/itensors)

# Publish the wheel to [PyPI](https://pypi.org/project/itensors/)

```bash
poetry publish --build
```